<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
      @submit.native.prevent
    >
      <el-form-item label="舰艇类型" prop="typeName">
        <el-input
          v-model="queryParams.typeName"
          placeholder="请输入舰艇类型"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:device:add']"
          >新增</el-button
        >
      </el-col>
    </el-row>

    <el-table
      v-loading="loading"
      :data="deviceList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column label="序号" align="center" type="index" />
      <el-table-column label="舰艇类型名称" align="center" prop="typeName" />
      <el-table-column label="舰艇型号名称" align="center" prop="shipDesign" />
      <el-table-column label="吨位(吨)" align="center" prop="tonnage" />
      <el-table-column label="吃水(米)" align="center" prop="draft" />
      <el-table-column label="舰长(米)" align="center" prop="length" />
      <el-table-column label="定员(人)" align="center" prop="crew" />
      <!-- <el-table-column label="target" min-width="500" align="center" prop="target" />
      <el-table-column label="position" min-width="500" align="center" prop="position" /> -->
      <el-table-column
        label="设备概述"
        min-width="1000"
        align="center"
        prop="shipOverview"
      />
      <el-table-column
        label="设备参数"
        min-width="1000"
        align="center"
        prop="shipParameters"
      />
      <el-table-column label="操作"  min-width="100" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:device:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:device:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改舰艇设备对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="舰艇类型名称" prop="typeName">
          <el-input v-model="form.typeName" placeholder="请输入舰艇类型名称" />
        </el-form-item>
        <el-form-item label="舰艇型号名称" prop="shipDesign">
          <el-input v-model="form.shipDesign" placeholder="请输入舰艇型号名称" />
        </el-form-item>
        <el-form-item label="吨位(吨)" prop="tonnage">
          <el-input v-model="form.tonnage" type="textarea" placeholder="请输入设备概述" />
        </el-form-item>
        <el-form-item label="吃水(米)" prop="draft">
          <el-input v-model="form.draft" type="textarea" placeholder="请输入设备概述" />
        </el-form-item>
        <el-form-item label="舰长(米)" prop="length">
          <el-input v-model="form.length" type="textarea" placeholder="请输入设备概述" />
        </el-form-item>
        <el-form-item label="定员(人)" prop="crew">
          <el-input v-model="form.crew" type="textarea" placeholder="请输入设备概述" />
        </el-form-item>
        <el-form-item label="position" prop="position">
          <el-input v-model="form.position" placeholder="请输入position" />
        </el-form-item>
        <el-form-item label="target " prop="target ">
          <el-input v-model="form.target" placeholder="请输入target" />
        </el-form-item>
        <el-form-item label="设备概述" prop="shipOverview">
          <el-input
            v-model="form.shipOverview"
            type="textarea"
            placeholder="请输入设备概述"
          />
        </el-form-item>
        <el-form-item label="设备参数" prop="shipParameters">
          <el-input
            v-model="form.shipParameters"
            type="textarea"
            placeholder="请输入设备参数"
          />
        </el-form-item>
        <el-form-item label="模型文件" prop="shipModel">
          <el-upload
            class="upload-demo"
            :action="uploadFileUrl"
            :on-remove="handleRemove"
            :on-success="handleAvatarSuccess"
            :file-list="fileList"
          >
            <el-button size="small" type="primary">点击上传</el-button>
            <!-- <div slot="tip" class="el-upload__tip">
              只能上传jpg/png文件，且不超过500kb
            </div> -->
          </el-upload>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listSipType,
  getdpShipType,
  deldpShipType,
  adddpShipType,
  updatedpShipType,
} from "@/api/manage/shipType";

const baseUrl = process.env.VUE_APP_BASE_API;

export default {
  name: "Device",
  data() {
    return {
      // 遮罩层
      loading: true,
      fileList: [],
      imageUrl: "",
      // 选中数组
      ids: [],
      shipOptions: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 舰艇设备表格数据
      deviceList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        deviceId: null,
        deviceName: null,
        deviceShipId: null,
        deviceOverview: null,
        shipModel: null,
        deviceParameters: null,
        updateTime: null,
        updateUser: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        deviceId: [{ required: true, message: "设备编号不能为空", trigger: "blur" }],
      },
      uploadFileUrl: baseUrl + "common/upload",
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询舰艇设备列表 */
    getList() {
      this.loading = true;
      listSipType(this.queryParams).then((response) => {
        this.deviceList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        deviceId: null,
        deviceName: null,
        deviceShipId: null,
        deviceOverview: null,
        shipModel: null,
        deviceParameters: null,
        updateTime: null,
        updateUser: null,
        ID: null,
      };
      this.resetForm("form");
      this.fileList = [];
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.ID);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.imageUrl = "";
      // shipList().then(response=>{
      //   this.shipOptions = response.data;
      // })
      this.open = true;
      this.title = "添加舰艇设备类型";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id;
      getdpShipType(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改舰艇设备类型";
        var fileListStr = response.data.shipModel;
        this.imageUrl = fileListStr == null ? "" : fileListStr;
        if (fileListStr) {
          if (fileListStr.endsWith(",")) {
            this.imageUrl = fileListStr;
            fileListStr = fileListStr.slice(0, -1); // 删除最后一个字符（逗号）
          } else {
            this.imageUrl = fileListStr + ",";
          }
          const arr = fileListStr.split(","); // 将文件路径字符串拆分成数组
          this.fileList = arr.map((item, index) => ({
            name: item.split("/").pop(), // 提取文件名
            url: baseUrl.slice(0, -1) + item, // 拼接完整的文件 URL
            status: "success", // 上传状态设置为成功
            uid: `uid-${index}`, // 使用唯一的 uid
          }));
        } else {
          this.imageUrl = "";
        }
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updatedpShipType(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            adddpShipType(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const id = row.id;
      this.$modal
        .confirm('是否确认删除舰艇设备型号为"' + row.shipDesign + '"的数据项？')
        .then(function () {
          return deldpShipType(id);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    handleRemove(file, fileList) {
      // var fileUrl = this.imageUrl.replace(file.response.fileName + ",", "");
      // this.form.shipModel = fileUrl;
      // console.log(this.form.shipModel);
      // console.log(baseUrl.slice(0, -1))
      const remainingUrls = fileList.map((item) =>
        item.url.replace(baseUrl.slice(0, -1), "")
      );
      this.form.shipModel = remainingUrls.join(",");
      this.imageUrl = remainingUrls.join(",");
      // console.log(this.form.shipModel);
    },
    handleAvatarSuccess(res, file) {
      this.imageUrl += res.fileName + ",";
      this.form.shipModel = this.imageUrl;
      console.log(this.form.shipModel);
    },
  },
};
</script>
